@@ -23,13 +23,9 @@
 */
 #include <config.h>
 
-#include <libgnome/gnome-macros.h>
+#include <string.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <eel/eel-string.h>
+#include <gio/gio.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-thumbnails.h>
@@ -40,9 +36,9 @@
 #define ICON_TEXT_ATTRIBUTES_NUM_ITEMS		3
 #define ICON_TEXT_ATTRIBUTES_DEFAULT_TOKENS	"size,date_modified,type"
 
-GNOME_CLASS_BOILERPLATE (FMIconContainer, fm_icon_container,
-			 NautilusIconContainer,
-			 nautilus_icon_container_get_type ())
+G_DEFINE_TYPE (FMIconContainer, fm_icon_container, NAUTILUS_TYPE_ICON_CONTAINER);
+
+static GQuark attribute_none_q;
 
 static FMIconView *
 get_icon_view (NautilusIconContainer *container)
@@ -51,17 +47,23 @@ get_icon_view (NautilusIconContainer *container)
 	return ((FMIconContainer *)container)->view;
 }
 
-static char *
+static NautilusIconInfo *
 fm_icon_container_get_icon_images (NautilusIconContainer *container,
 				   NautilusIconData      *data,
-				   GList                **emblem_icons,
+				   int                    size,
+				   GList                **emblem_pixbufs,
 				   char                 **embedded_text,
+				   gboolean               for_drag_accept,
+				   gboolean               need_large_embeddded_text,
 				   gboolean              *embedded_text_needs_loading,
 				   gboolean              *has_window_open)
 {
 	FMIconView *icon_view;
-	EelStringList *emblems_to_ignore;
+	char **emblems_to_ignore;
 	NautilusFile *file;
+	gboolean use_embedding;
+	NautilusFileIconFlags flags;
+	guint emblem_size;
 
 	file = (NautilusFile *) data;
 
@@ -69,21 +71,44 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 	icon_view = get_icon_view (container);
 	g_return_val_if_fail (icon_view != NULL, NULL);
 
+	use_embedding = FALSE;
 	if (embedded_text) {
-		*embedded_text = nautilus_file_peek_top_left_text (file, embedded_text_needs_loading);
+		*embedded_text = nautilus_file_peek_top_left_text (file, need_large_embeddded_text, embedded_text_needs_loading);
+		use_embedding = *embedded_text != NULL;
 	}
 	
-	if (emblem_icons != NULL) {
-		emblems_to_ignore = fm_directory_view_get_emblem_names_to_exclude 
-			(FM_DIRECTORY_VIEW (icon_view));
-		*emblem_icons = nautilus_icon_factory_get_emblem_icons_for_file
-			(file, emblems_to_ignore);
-		eel_string_list_free (emblems_to_ignore);
+	if (emblem_pixbufs != NULL) {
+		emblem_size = nautilus_icon_get_emblem_size_for_icon_size (size);
+		/* don't return images larger than the actual icon size */
+		emblem_size = MIN (emblem_size, size);
+
+		if (emblem_size > 0) {
+			emblems_to_ignore = fm_directory_view_get_emblem_names_to_exclude 
+				(FM_DIRECTORY_VIEW (icon_view));
+			*emblem_pixbufs = nautilus_file_get_emblem_pixbufs (file,
+									    emblem_size,
+									    FALSE,
+									    emblems_to_ignore);
+			g_strfreev (emblems_to_ignore);
+		}
 	}
 
 	*has_window_open = nautilus_file_has_open_window (file);
+
+	flags = 0;
+	if (!fm_icon_view_is_compact (icon_view) ||
+	    nautilus_icon_container_get_zoom_level (container) > NAUTILUS_ZOOM_LEVEL_STANDARD) {
+		flags |= NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS;
+	}
+
+	if (use_embedding) {
+		flags |= NAUTILUS_FILE_ICON_FLAGS_EMBEDDING_TEXT;
+	}
+	if (for_drag_accept) {
+		flags |= NAUTILUS_FILE_ICON_FLAGS_FOR_DRAG_ACCEPT;
+	}
 	
-	return nautilus_icon_factory_get_icon_for_file (file, TRUE);
+	return nautilus_file_get_icon (file, size, flags);
 }
 
 static char *
@@ -102,7 +127,7 @@ fm_icon_container_get_icon_description (NautilusIconContainer *container,
 	}
 
 	mime_type = nautilus_file_get_mime_type (file);
-	description = gnome_vfs_mime_get_description (mime_type);
+	description = g_content_type_get_description (mime_type);
 	g_free (mime_type);
 	return g_strdup (description);
 }
@@ -110,15 +135,21 @@ fm_icon_container_get_icon_description (NautilusIconContainer *container,
 static void
 fm_icon_container_start_monitor_top_left (NautilusIconContainer *container,
 					  NautilusIconData      *data,
-					  gconstpointer          client)
+					  gconstpointer          client,
+					  gboolean               large_text)
 {
 	NautilusFile *file;
-
+	NautilusFileAttributes attributes;
+		
 	file = (NautilusFile *) data;
 
 	g_assert (NAUTILUS_IS_FILE (file));
 
-	nautilus_file_monitor_add (file, client, NAUTILUS_FILE_ATTRIBUTE_TOP_LEFT_TEXT);
+	attributes = NAUTILUS_FILE_ATTRIBUTE_TOP_LEFT_TEXT;
+	if (large_text) {
+		attributes |= NAUTILUS_FILE_ATTRIBUTE_LARGE_TOP_LEFT_TEXT;
+	}
+	nautilus_file_monitor_add (file, client, attributes);
 }
 
 static void
@@ -153,26 +184,20 @@ fm_icon_container_prioritize_thumbnailing (NautilusIconContainer *container,
 	}
 }
 
-
 /*
  * Get the preference for which caption text should appear
  * beneath icons.
  */
-static EelStringList *
+static GQuark *
 fm_icon_container_get_icon_text_attributes_from_preferences (void)
 {
-	static const EelStringList *attributes;
+	static GQuark *attributes = NULL;
 
 	if (attributes == NULL) {
-		eel_preferences_add_auto_string_list (NAUTILUS_PREFERENCES_ICON_VIEW_CAPTIONS,
-						      &attributes);
+		eel_preferences_add_auto_string_array_as_quarks (NAUTILUS_PREFERENCES_ICON_VIEW_CAPTIONS,
+								 &attributes);
 	}
-
-	/* A simple check that the attributes list matches the expected length */
-	g_return_val_if_fail (eel_string_list_get_length (attributes) == ICON_TEXT_ATTRIBUTES_NUM_ITEMS,
-			      eel_string_list_new_from_tokens (ICON_TEXT_ATTRIBUTES_DEFAULT_TOKENS, ",", TRUE));
-
-
+	
 	/* We don't need to sanity check the attributes list even though it came
 	 * from preferences.
 	 *
@@ -193,31 +218,40 @@ fm_icon_container_get_icon_text_attributes_from_preferences (void)
 	 * duplicate attributes by making "bad" choices insensitive.
 	 *
 	 * In the second case, the preferences getter (and also the auto storage) for
-	 * string_list values are always valid members of the enumeration associated
+	 * string_array values are always valid members of the enumeration associated
 	 * with the preference.
 	 *
 	 * So, no more error checking on attributes is needed here and we can return
-	 * a copy of the auto stored value.
+	 * a the auto stored value.
 	 */
-	return eel_string_list_copy (attributes);
+	return attributes;
+}
+
+static int
+quarkv_length (GQuark *attributes)
+{
+	int i;
+	i = 0;
+	while (attributes[i] != 0) {
+		i++;
+	}
+	return i;
 }
 
 /**
  * fm_icon_view_get_icon_text_attribute_names:
  *
- * Get a string representing which text attributes should be displayed
+ * Get a list representing which text attributes should be displayed
  * beneath an icon. The result is dependent on zoom level and possibly
- * user configuration. Use g_free to free the result.
+ * user configuration. Don't free the result.
  * @view: FMIconView to query.
  * 
- * Return value: A |-delimited string comprising attribute names, e.g. "name|size".
- * 
  **/
-static char *
-fm_icon_container_get_icon_text_attribute_names (NautilusIconContainer *container)
+static GQuark *
+fm_icon_container_get_icon_text_attribute_names (NautilusIconContainer *container,
+						 int *len)
 {
-	EelStringList *attributes;
-	char *result;
+	GQuark *attributes;
 	int piece_count;
 
 	const int pieces_by_level[] = {
@@ -231,14 +265,12 @@ fm_icon_container_get_icon_text_attribute_names (NautilusIconContainer *containe
 	};
 
 	piece_count = pieces_by_level[nautilus_icon_container_get_zoom_level (container)];
-	
-	attributes = fm_icon_container_get_icon_text_attributes_from_preferences ();
-	g_return_val_if_fail ((guint)piece_count <= eel_string_list_get_length (attributes), NULL);
-	
-	result = eel_string_list_as_string (attributes, "|", piece_count);
-	eel_string_list_free (attributes);
 
-	return result;
+	attributes = fm_icon_container_get_icon_text_attributes_from_preferences ();
+
+	*len = MIN (piece_count, quarkv_length (attributes));
+
+	return attributes;
 }
 
 /* This callback returns the text, both the editable part, and the
@@ -252,10 +284,9 @@ fm_icon_container_get_icon_text (NautilusIconContainer *container,
 {
 	char *actual_uri;
 	gchar *description;
-	char *attribute_names;
-	char **text_array;
-	int i , slot_index;
-	char *attribute_string;
+	GQuark *attributes;
+	char *text_array[4];
+	int i, j, num_attributes;
 	FMIconView *icon_view;
 	NautilusFile *file;
 
@@ -275,6 +306,11 @@ fm_icon_container_get_icon_text (NautilusIconContainer *container,
 		*editable_text = nautilus_file_get_display_name (file);
 	}
 
+	if (fm_icon_view_is_compact (icon_view)) {
+		*additional_text = NULL;
+		return;
+	}
+
 	if (NAUTILUS_IS_DESKTOP_ICON_FILE (file)) {
 		/* Don't show the normal extra information for desktop icons, it doesn't
 		 * make sense. */
@@ -298,42 +334,36 @@ fm_icon_container_get_icon_text (NautilusIconContainer *container,
 		 * make sense. */
 		return;
 	}
-	
+
 	/* Find out what attributes go below each icon. */
-	attribute_names = fm_icon_container_get_icon_text_attribute_names (container);
-	text_array = g_strsplit (attribute_names, "|", 0);
-	g_free (attribute_names);
+	attributes = fm_icon_container_get_icon_text_attribute_names (container,
+									   &num_attributes);
 
 	/* Get the attributes. */
-	for (i = 0; text_array[i] != NULL; i++)	{
-		/* if the attribute is "none", delete the array slot */
-		while (eel_strcmp (text_array[i], "none") == 0) {
-			g_free (text_array[i]);
-			text_array[i] = NULL;
-			slot_index = i + 1;			
-			while (text_array[slot_index] != NULL) {
-				text_array[slot_index - 1] = text_array[slot_index];
-				text_array[slot_index++] = NULL;
-			}
-			if (text_array[i] == NULL)
-				break;
-		} 
-		
-		if (text_array[i] == NULL)
-			break;
-			
-		attribute_string = nautilus_file_get_string_attribute_with_default
-			(file, text_array[i]);
-				
-		/* Replace each attribute name in the array with its string value */
-		g_free (text_array[i]);
-		text_array[i] = attribute_string;
+	j = 0;
+	for (i = 0; i < num_attributes; ++i) {
+		if (attributes[i] == attribute_none_q) {
+			continue;
+		}
+
+		text_array[j++] =
+			nautilus_file_get_string_attribute_with_default_q (file, attributes[i]);
 	}
+	text_array[j] = NULL;
 
 	/* Return them. */
-	*additional_text = g_strjoinv ("\n", text_array);
-
-	g_strfreev (text_array);
+	if (j == 0) {
+		*additional_text = NULL;
+	} else if (j == 1) {
+		/* Only one item, avoid the strdup + free */
+		*additional_text = text_array[0];
+	} else {
+		*additional_text = g_strjoinv ("\n", text_array);
+		
+		for (i = 0; i < j; i++) {
+			g_free (text_array[i]);
+		}
+	}
 }
 
 /* Sort as follows:
@@ -371,7 +401,7 @@ get_sort_category (NautilusFile *file)
 			case NAUTILUS_DESKTOP_LINK_HOME:
 				category = SORT_HOME_LINK;
 				break;
-			case NAUTILUS_DESKTOP_LINK_VOLUME:
+			case NAUTILUS_DESKTOP_LINK_MOUNT:
 				category = SORT_MOUNT_LINK;
 				break;
 			case NAUTILUS_DESKTOP_LINK_TRASH:
@@ -457,6 +487,24 @@ fm_icon_container_compare_icons_by_name (NautilusIconContainer *container,
 		 FALSE, FALSE);
 }
 
+static void
+fm_icon_container_freeze_updates (NautilusIconContainer *container)
+{
+	FMIconView *icon_view;
+	icon_view = get_icon_view (container);
+	g_return_if_fail (icon_view != NULL);
+	fm_directory_view_freeze_updates (FM_DIRECTORY_VIEW (icon_view));
+}
+
+static void
+fm_icon_container_unfreeze_updates (NautilusIconContainer *container)
+{
+	FMIconView *icon_view;
+	icon_view = get_icon_view (container);
+	g_return_if_fail (icon_view != NULL);
+	fm_directory_view_unfreeze_updates (FM_DIRECTORY_VIEW (icon_view));
+}
+
 static void
 fm_icon_container_dispose (GObject *object)
 {
@@ -466,7 +514,7 @@ fm_icon_container_dispose (GObject *object)
 
 	icon_container->view = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+	G_OBJECT_CLASS (fm_icon_container_parent_class)->dispose (object);
 }
 
 static void
@@ -476,6 +524,8 @@ fm_icon_container_class_init (FMIconContainerClass *klass)
 
 	ic_class = &klass->parent_class;
 
+	attribute_none_q = g_quark_from_static_string ("none");
+	
 	ic_class->get_icon_text = fm_icon_container_get_icon_text;
 	ic_class->get_icon_images = fm_icon_container_get_icon_images;
 	ic_class->get_icon_description = fm_icon_container_get_icon_description;
@@ -485,12 +535,14 @@ fm_icon_container_class_init (FMIconContainerClass *klass)
 
 	ic_class->compare_icons = fm_icon_container_compare_icons;
 	ic_class->compare_icons_by_name = fm_icon_container_compare_icons_by_name;
+	ic_class->freeze_updates = fm_icon_container_freeze_updates;
+	ic_class->unfreeze_updates = fm_icon_container_unfreeze_updates;
 
 	G_OBJECT_CLASS (klass)->dispose = fm_icon_container_dispose;
 }
 
 static void
-fm_icon_container_instance_init (FMIconContainer *icon_container)
+fm_icon_container_init (FMIconContainer *icon_container)
 {
 }
 
